import unittest
from types import ModuleType

from linkml.generators.pythongen import PythonGenerator

from biolink import BIOLINK_MODEL_YAML


class PythonGenTestCase(unittest.TestCase):
    def gen_and_comp_python(self, yaml_file: str) -> None:
        """
         Generate a python image of the metamodel and verify that it parses
        :param yaml_file: YAML model definition

        """
        model_python = PythonGenerator(yaml_file).serialize()

        spec = compile(model_python, 'test', 'exec')
        module = ModuleType('test')
        exec(spec, module.__dict__)

    def test_biolinkmodel(self):
        self.gen_and_comp_python(BIOLINK_MODEL_YAML)


if __name__ == '__main__':
    unittest.main()



# Biolink model file locations
import os

basedir = os.path.abspath(os.path.join(__file__, '..', '..'))
BIOLINK_MODEL_YAML = os.path.join(basedir, 'biolink-model.yaml')
BIOLINK_MODEL_JSONLD = os.path.join(basedir, 'context.jsonld')
BIOLINK_MODEL_SHEX = os.path.join(basedir, 'shex', 'biolink-model.shex')
BIOLINK_MODEL_RDF = os.path.join(basedir, 'rdf', 'biolink-model.ttl')
BIOLINK_MODEL_OWL = os.path.join(basedir, 'ontology', 'biolink-model.owl')
BIOLINK_MODEL_JSON = os.path.join(basedir, 'biolink-model.json')
BIOLINK_MODEL_JSON_SCHEMA = os.path.join(basedir, 'json-schema', 'biolink-model.json')
BIOLINK_MODEL_JAVA = os.path.join(basedir, 'java')
BIOLINK_MODEL_PYTHON = os.path.join(basedir, 'biolink', 'model.py')



import unittest

from linkml.utils.schemaloader import SchemaLoader

from biolink import BIOLINK_MODEL_YAML


class BiolinkModelTestCase(unittest.TestCase):
    def test_biolink_model(self):
        """ Make sure the biolink model is valid """
        schema = SchemaLoader(BIOLINK_MODEL_YAML)
        errors = []
        try:
            schema.resolve()
        except ValueError as e:
            errors.append(str(e))
        if not errors:
            errors = schema.synopsis.errors()
        self.assertEqual([], errors, "biolink-model.yaml - errors detected")


if __name__ == '__main__':
    unittest.main()
